Crate phantom_frame

Crate phantom_frame 

Modules

cache
compression
config
control
path_matcher
proxy

Structs

CreateProxyConfig
Configuration for creating a proxy
RequestInfo
Information about an incoming request for cache key generation

Enums

CacheStorageMode
Controls where cached response bodies are stored.
CacheStrategy
Controls which backend responses are eligible for caching.
CompressStrategy
Controls how cacheable responses are stored in memory.

Functions

create_proxy
The main library interface for using phantom-frame as a library Returns a proxy handler function and a refresh trigger
create_proxy_with_trigger
Create a proxy handler with an existing refresh trigger