pub enum InvalidationMessage {
All,
Pattern(String),
}Expand description
Messages sent via the broadcast channel to invalidate cache entries.
Variants
All
Invalidate all cache entries.
Pattern(String)
Invalidate cache entries whose key matches a pattern (supports wildcards).