Modules
Structs
- Create
Proxy Config - Configuration for creating a proxy
- Request
Info - Information about an incoming request for cache key generation
Enums
- Cache
Storage Mode - Controls where cached response bodies are stored.
- Cache
Strategy - Controls which backend responses are eligible for caching.
- Compress
Strategy - Controls how cacheable responses are stored in memory.
Functions
- create_
proxy - The main library interface for using phantom-frame as a library Returns a proxy handler function and a refresh trigger
- create_
proxy_ with_ trigger - Create a proxy handler with an existing refresh trigger